pub enum DeviceEvent {
ManualLock {
user_id: UserId,
},
ManualUnlock {
user_id: UserId,
user_key: Vec<u8>,
},
}Expand description
The device (client) has several events that need to be reported to the shared unlock system. This enum represents the events that need to be reported.
Variants
ManualLock
The user with the given user id has been locked manually in the UI
Fields

user_id: UserIdUser whose vault was manually locked.
ManualUnlock
The user with the given user id has been unlocked manually in the UI