pub enum SharedUnlockClient {
Browser,
Desktop,
Web,
}Expand description
A kind of client a peer may share unlock state with, independent of the IPC endpoint variants that address its individual contexts (foreground/background, renderer/main).
Variants
Browser
The browser extension, in any of its contexts.
Desktop
The desktop app, in any of its processes.
Web
A web vault tab.
Implementations
Sourcepub(crate) fn of_endpoint(endpoint: &Endpoint) -> Self
pub(crate) fn of_endpoint(endpoint: &Endpoint) -> Self
The client an endpoint belongs to.